Trait syncbox::Delayed
[−]
[src]
pub trait Delayed {
fn delay(&self) -> Duration;
}A value that should not be used until the delay has expired.
pub trait Delayed {
fn delay(&self) -> Duration;
}A value that should not be used until the delay has expired.